pub enum ChainError<E> {
Malformed(MalformedChain),
ResetRace {
chain: QueueEpoch,
current: QueueEpoch,
},
Transport(E),
}Expand description
Failure to expose one consumed chain as validated byte ports.
Variants
Malformed(MalformedChain)
The chain is malformed and should be completed with used length zero when recoverable.
ResetRace
Reset invalidated this chain before byte access.
Transport(E)
Concrete transport or memory-access failure.