pub enum MalformedChain {
DescriptorLoop,
DescriptorIndex,
DescriptorFlags,
DescriptorCount,
ZeroLength,
Direction,
LengthOverflow,
PortLengthMismatch,
IndirectUnsupported,
IndirectMalformed,
Address,
}Expand description
Structurally malformed descriptor-chain classification.
Variants
DescriptorLoop
A descriptor chain contains a loop.
DescriptorIndex
A descriptor index is outside the configured queue.
DescriptorFlags
A descriptor contains flags outside the negotiated split-ring profile.
DescriptorCount
The flattened descriptor count is invalid.
ZeroLength
A descriptor has zero length.
Direction
Readable and writable descriptor ordering is invalid.
LengthOverflow
Descriptor byte totals overflow.
PortLengthMismatch
Mapped byte ports do not match descriptor byte totals.
IndirectUnsupported
An indirect descriptor was offered without negotiation.
IndirectMalformed
An indirect descriptor table is structurally invalid.
Address
A descriptor range cannot be mapped for the required access.