pub enum NotificationHint {
Suppressed,
Notify,
}Expand description
Whether the peer should be notified after a publication operation.
Variants
Suppressed
Notification is suppressed by current queue state.
Notify
The peer should be notified after the publication barrier.