QueuePort

Trait QueuePort 

pub trait QueuePort {
    // Required method
    fn state(&self) -> QueueState;
}
Read-only state shared by driver, device, and configuration ports.

Required Methods

fn state(&self) -> QueueState

Return a coherent queue-state snapshot.

This operation must not block or allocate. Implementations using shared state must use acquire ordering sufficient to observe the corresponding configuration and reset writes.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors