pub trait QueueControl: QueuePort {
type Error;
// Required methods
fn configure(
&mut self,
size: QueueSize,
) -> Result<(), QueueError<Self::Error>>;
fn set_ready(&mut self, ready: bool) -> Result<(), QueueError<Self::Error>>;
}Expand description
Queue configuration control plane.
Required Associated Types
Required Methods
Sourcefn configure(&mut self, size: QueueSize) -> Result<(), QueueError<Self::Error>>
fn configure(&mut self, size: QueueSize) -> Result<(), QueueError<Self::Error>>
Configure queue size while the queue is not ready.
This operation must not block. It may allocate storage bounded by size; implementations
must report allocation failure through Error without changing the prior configuration.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".